@@ -11,7 +11,7 @@ use IO::All;
 # manual import ;-)
 *cvcb = \&AnyEvent::CouchDB::cvcb;
 
-our $query = sub { 
+our $query = sub {
   my $options = shift;
   my @buf;
   if (defined($options) && keys %$options) {
@@ -21,7 +21,7 @@ our $query = sub {
       if ($name eq 'key' || $name eq 'startkey' || $name eq 'endkey') {
         $value = ref($value) ? encode_json($value) : (defined $value) ? qq{"$value"} : 'null';
       }
-      if ($name eq 'group') {
+      if ($name eq 'group' || $name eq 'reduce' || $name eq 'descending' || $name eq 'include_docs') {
         $value = $value
           ? ( ($value eq 'false') ? 'false' : 'true' )
           : 'false';
@@ -30,7 +30,7 @@ our $query = sub {
     }
   }
   (@buf)
-    ? '?' . join('&', @buf) 
+    ? '?' . join('&', @buf)
     : '';
 };
 
@@ -105,6 +105,13 @@ sub all_docs {
   $cv;
 }
 
+sub all_docs_by_seq {
+  my ($self, $options) = @_;
+  my ($cv, $cb) = cvcb($options);
+  http_get($self->uri.'_all_docs_by_seq'.$query->($options), $cb);
+  $cv;
+}
+
 sub open_doc {
   my ($self, $doc_id, $options) = @_;
   my ($cv, $cb) = cvcb($options);
@@ -277,7 +284,19 @@ sub query {
 sub view {
   my ($self, $name, $options) = @_;
   my ($cv, $cb) = cvcb($options);
-  http_get($self->uri."_view/".$name.$query->($options), $cb);
+  my ($dname, $vname) = split('/', $name);
+  my $uri = $self->uri."/_design/".$dname."/_view/".$vname;
+  if ($options->{keys}) {
+    my $body = { keys => $options->{keys} };
+    http_request(
+      'POST' => $uri,
+      headers => { 'Content-Type' => 'application/json' },
+      body    => encode_json($body),
+      $cb
+    );
+  } else {
+    http_get($uri.$query->($options), $cb);
+  }
   $cv;
 }
 
@@ -351,13 +370,6 @@ be compacted, and it returns a condvar.
 
 =head2 Document Level Operations
 
-=head3 $cv = $db->all_docs([ \%options ])
-
-This method is used to request a hashref that contains an index of all the
-documents in the database.  Note that you B<DO NOT> get the actual documents.
-Instead, you get their C<id>s, so that you can fetch them later.
-To get the documents in the result, set parameter C<include_docs> to 1 in the options
-
 =head3 $cv = $db->open_doc($id, [ \%options ])
 
 This method is used to request a single CouchDB document by its C<id>, and
@@ -412,6 +424,31 @@ return a condvar.
 
 =head2 Database Queries
 
+=head3 $cv = $db->view($name, [ \%options ])
+
+This method lets you query views that have been predefined in CouchDB design
+documents.  You give it a name which is of the form "$design_doc/$view", and
+you may pass in C<\%options> as well to manipulate the result-set.
+
+This method returns a condvar.
+
+=head3 $cv = $db->all_docs([ \%options ])
+
+This method is used to request a hashref that contains an index of all the
+documents in the database.  Note that you B<DO NOT> get the actual documents.
+Instead, you get their C<id>s, so that you can fetch them later.
+To get the documents in the result, set parameter C<include_docs> to 1 in 
+the C<\%options>.
+
+=head3 $cv = $db->all_docs_by_seq([ \%options ])
+
+This method is similar to the C<all_docs> method, but instead of using document ids
+as a key, it uses update sequence of the document instead.  (The update_seq is an
+integer that is incremented every time the database is updated.  You can get the
+current update_seq of a database by calling C<info>.)
+
+This method returns a condvar.
+
 =head3 $cv = $db->query($map, [ $reduce ], [ $language ], [ \%options ])
 
 This method lets you send ad-hoc queries to CouchDB.  You have to at least give
@@ -425,21 +462,13 @@ C<\%options>, can be used to manipulate the result-set in standard ways.
 
 This method returns a condvar.
 
-=head3 $cv = $db->view($name, [ \%options ])
-
-This method lets you query views that have been predefined in CouchDB design
-documents.  You give it a name which is of the form "$design_doc/$view", and
-you may pass in C<\%options> as well to manipulate the result-set.
-
-This method returns a condvar.
-
 =head1 AUTHOR
 
 John BEPPU E<lt>beppu@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008 John BEPPU E<lt>beppu@cpan.orgE<gt>.
+Copyright (c) 2008-2009 John BEPPU E<lt>beppu@cpan.orgE<gt>.
 
 =head2 The "MIT" License
 
